@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
 our $DATE = '2016-12-15'; # DATE
-our $VERSION = '1.65'; # VERSION
+our $VERSION = '1.66'; # VERSION
 
 use 5.010001;
 use strict;
@@ -830,10 +830,6 @@ sub _parse_argv1 {
         $r->{subcommand_data} = $scd;
     }
 
-    # also set dry-run on environment
-    $r->{dry_run} = defined($ENV{DRY_RUN}) ? ($ENV{DRY_RUN} ? 1:0) :
-        $self->default_dry_run;
-
     $r->{_parse_argv1_done} = 1;
 }
 
@@ -1456,7 +1452,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.65 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-15.
+This document describes version 1.66 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-15.
 
 =head1 DESCRIPTION
 
